utils::globalVariables(
    c(".index", ".key", ".value", ".model_id", ".loadings", ".model", ".model_desc",
      ".pred", ".predictions", ".resample_results", ".row_id", ".preds", ".type",
      "n", ".resample_id")
)
